@@ -1,11 +1,11 @@
 package Gearman::Client;
-$Gearman::Client::VERSION = '1.12.008';
+$Gearman::Client::VERSION = '1.12.009';
 
 use strict;
 use warnings;
 no warnings "redefine";
 
-use base 'Gearman::Object';
+use base 'Gearman::Objects';
 
 use fields (
     'sock_cache',    # hostport -> socket
